@@ -21,6 +21,9 @@ from unittest import mock
 
 import pytest
 
+from tests_common.test_utils.compat import timezone
+from tests_common.test_utils.db import clear_db_dags, clear_db_runs, clear_rendered_ti_fields
+from tests_common.test_utils.taskinstance import get_template_context
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
 
 if AIRFLOW_V_3_0_PLUS:
@@ -28,10 +31,6 @@ if AIRFLOW_V_3_0_PLUS:
 else:
     from airflow.decorators import setup, task, teardown  # type: ignore[attr-defined,no-redef]
 
-from airflow.utils import timezone
-
-from tests_common.test_utils.db import clear_db_dags, clear_db_runs, clear_rendered_ti_fields
-
 TASK_FUNCTION_NAME_ID = "task_function_name"
 DEFAULT_DATE = timezone.datetime(2023, 1, 1)
 DAG_ID = "k8s_deco_test_dag"
@@ -124,8 +123,7 @@ class TestKubernetesDecoratorsBase:
         session = self.dag_maker.session
         dag_run = self.dag_maker.create_dagrun(run_id=f"k8s_decorator_test_{DEFAULT_DATE.date()}")
         ti = dag_run.get_task_instance(task.operator.task_id, session=session)
-        return_val = task.operator.execute(context=ti.get_template_context(session=session))
-
+        return_val = task.operator.execute(context=get_template_context(ti, task.operator, session=session))
         return ti, return_val
 
 
