@@ -37,10 +37,12 @@ from airflow.models import Connection, DagRun, TaskInstance
 from airflow.providers.cncf.kubernetes.operators.spark_kubernetes import SparkKubernetesOperator
 from airflow.providers.cncf.kubernetes.pod_generator import MAX_LABEL_LEN
 from airflow.providers.cncf.kubernetes.triggers.pod import KubernetesPodTrigger
+from airflow.providers.cncf.kubernetes.utils.pod_manager import PodPhase
 from airflow.providers.common.compat.sdk import TaskDeferred
 from airflow.utils import timezone
 from airflow.utils.types import DagRunType
 
+from tests_common.test_utils.taskinstance import create_task_instance
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
 
 POD_MANAGER_CLASS = "airflow.providers.cncf.kubernetes.utils.pod_manager.PodManager"
@@ -273,7 +275,7 @@ def create_context(task):
     if AIRFLOW_V_3_0_PLUS:
         from uuid6 import uuid7
 
-        task_instance = TaskInstance(task=task, dag_version_id=uuid7())
+        task_instance = create_task_instance(task=task, dag_version_id=uuid7())
     else:
         task_instance = TaskInstance(task=task)
     task_instance.dag_run = dag_run
@@ -861,7 +863,11 @@ class TestSparkKubernetesOperator:
         op.execute(context)
         label_selector = op._build_find_pod_label_selector(context) + ",spark-role=driver"
         op.find_spark_job(context)
-        mock_get_kube_client.list_namespaced_pod.assert_called_with("default", label_selector=label_selector)
+        mock_get_kube_client.list_namespaced_pod.assert_called_with(
+            "default",
+            label_selector=label_selector,
+            field_selector=op._get_field_selector(),
+        )
 
     @patch("airflow.providers.cncf.kubernetes.hooks.kubernetes.KubernetesHook")
     def test_adds_task_context_labels_to_driver_and_executor(
@@ -939,10 +945,288 @@ class TestSparkKubernetesOperator:
         op.execute(context)
 
         label_selector = op._build_find_pod_label_selector(context) + ",spark-role=driver"
-        mock_get_kube_client.list_namespaced_pod.assert_called_with("default", label_selector=label_selector)
+        mock_get_kube_client.list_namespaced_pod.assert_called_with(
+            "default",
+            label_selector=label_selector,
+            field_selector=op._get_field_selector(),
+        )
 
         mock_create_namespaced_crd.assert_not_called()
 
+    def test_find_spark_job_picks_non_terminating_pod(
+        self,
+        mock_is_in_cluster,
+        mock_parent_execute,
+        mock_create_namespaced_crd,
+        mock_get_namespaced_custom_object_status,
+        mock_cleanup,
+        mock_create_job_name,
+        mock_get_kube_client,
+        mock_create_pod,
+        mock_await_pod_completion,
+        mock_fetch_requested_container_logs,
+        data_file,
+    ):
+        """
+        Verifies that find_spark_job picks a non-terminating Spark driver pod over a terminating pod.
+        """
+
+        task_name = "test_find_spark_job_picks_non_terminating_pod"
+        job_spec = yaml.safe_load(data_file("spark/application_template.yaml").read_text())
+
+        mock_create_job_name.return_value = task_name
+        op = SparkKubernetesOperator(
+            template_spec=job_spec,
+            kubernetes_conn_id="kubernetes_default_kube_config",
+            task_id=task_name,
+            get_logs=True,
+            reattach_on_restart=True,
+        )
+        context = create_context(op)
+
+        # Non-terminating pod should be selected.
+        non_terminating_pod = mock.MagicMock()
+        non_terminating_pod.metadata.creation_timestamp = timezone.datetime(2025, 1, 1, tzinfo=timezone.utc)
+        non_terminating_pod.metadata.name = "spark-driver"
+        non_terminating_pod.metadata.labels = {"try_number": "1"}
+        non_terminating_pod.status.phase = PodPhase.RUNNING
+
+        # Terminating pod should not be selected.
+        terminating_pod = mock.MagicMock()
+        terminating_pod.metadata.creation_timestamp = timezone.datetime(2025, 1, 1, tzinfo=timezone.utc)
+        terminating_pod.metadata.deletion_timestamp = timezone.datetime(2025, 1, 2, tzinfo=timezone.utc)
+        terminating_pod.metadata.name = "spark-driver"
+        terminating_pod.metadata.labels = {"try_number": "1"}
+        terminating_pod.status.phase = PodPhase.RUNNING
+
+        mock_get_kube_client.list_namespaced_pod.return_value.items = [
+            non_terminating_pod,
+            terminating_pod,
+        ]
+
+        returned_pod = op.find_spark_job(context)
+
+        assert returned_pod is non_terminating_pod
+
+    def test_find_spark_job_picks_pending_pod(
+        self,
+        mock_is_in_cluster,
+        mock_parent_execute,
+        mock_create_namespaced_crd,
+        mock_get_namespaced_custom_object_status,
+        mock_cleanup,
+        mock_create_job_name,
+        mock_get_kube_client,
+        mock_create_pod,
+        mock_await_pod_completion,
+        mock_fetch_requested_container_logs,
+        data_file,
+    ):
+        """
+        Verifies that find_spark_job picks a Pending Spark driver pod over a Running pod.
+        """
+
+        task_name = "test_find_spark_job_prefers_pending_pod"
+        job_spec = yaml.safe_load(data_file("spark/application_template.yaml").read_text())
+
+        mock_create_job_name.return_value = task_name
+        op = SparkKubernetesOperator(
+            template_spec=job_spec,
+            kubernetes_conn_id="kubernetes_default_kube_config",
+            task_id=task_name,
+            get_logs=True,
+            reattach_on_restart=True,
+        )
+        context = create_context(op)
+
+        # Pending pod should be selected.
+        pending_pod = mock.MagicMock()
+        pending_pod.metadata.creation_timestamp = timezone.datetime(2025, 1, 1, tzinfo=timezone.utc)
+        pending_pod.metadata.name = "spark-driver"
+        pending_pod.metadata.labels = {"try_number": "1"}
+        pending_pod.status.phase = PodPhase.PENDING
+
+        # Running pod should not be selected.
+        running_pod = mock.MagicMock()
+        running_pod.metadata.creation_timestamp = timezone.datetime(2025, 1, 1, tzinfo=timezone.utc)
+        running_pod.metadata.name = "spark-driver"
+        running_pod.metadata.labels = {"try_number": "1"}
+        running_pod.status.phase = PodPhase.RUNNING
+
+        mock_get_kube_client.list_namespaced_pod.return_value.items = [
+            running_pod,
+            pending_pod,
+        ]
+
+        returned_pod = op.find_spark_job(context)
+
+        assert returned_pod is pending_pod
+
+    def test_find_spark_job_picks_succeeded(
+        self,
+        mock_is_in_cluster,
+        mock_parent_execute,
+        mock_create_namespaced_crd,
+        mock_get_namespaced_custom_object_status,
+        mock_cleanup,
+        mock_create_job_name,
+        mock_get_kube_client,
+        mock_create_pod,
+        mock_await_pod_completion,
+        mock_fetch_requested_container_logs,
+        data_file,
+    ):
+        """
+        Verifies that find_spark_job picks a Succeeded Spark driver pod over a pending pod.
+        """
+
+        task_name = "test_find_spark_job_prefers_succeeded_pod"
+        job_spec = yaml.safe_load(data_file("spark/application_template.yaml").read_text())
+
+        mock_create_job_name.return_value = task_name
+        op = SparkKubernetesOperator(
+            template_spec=job_spec,
+            kubernetes_conn_id="kubernetes_default_kube_config",
+            task_id=task_name,
+            get_logs=True,
+            reattach_on_restart=True,
+        )
+        context = create_context(op)
+
+        # Succeeded pod should be selected.
+        succeeded_pod = mock.MagicMock()
+        succeeded_pod.metadata.creation_timestamp = timezone.datetime(2025, 1, 1, tzinfo=timezone.utc)
+        succeeded_pod.metadata.name = "spark-driver"
+        succeeded_pod.metadata.labels = {"try_number": "1"}
+        succeeded_pod.status.phase = PodPhase.SUCCEEDED
+
+        # Pending pod should not be selected.
+        pending_pod = mock.MagicMock()
+        pending_pod.metadata.creation_timestamp = timezone.datetime(2025, 1, 1, tzinfo=timezone.utc)
+        pending_pod.metadata.name = "spark-driver"
+        pending_pod.metadata.labels = {"try_number": "1"}
+        pending_pod.status.phase = PodPhase.PENDING
+
+        mock_get_kube_client.list_namespaced_pod.return_value.items = [
+            pending_pod,
+            succeeded_pod,
+        ]
+
+        returned_pod = op.find_spark_job(context)
+
+        assert returned_pod is succeeded_pod
+
+    def test_find_spark_job_picks_latest_pod(
+        self,
+        mock_is_in_cluster,
+        mock_parent_execute,
+        mock_create_namespaced_crd,
+        mock_get_namespaced_custom_object_status,
+        mock_cleanup,
+        mock_create_job_name,
+        mock_get_kube_client,
+        mock_create_pod,
+        mock_await_pod_completion,
+        mock_fetch_requested_container_logs,
+        data_file,
+    ):
+        """
+        Verifies that find_spark_job selects the most recently created Spark driver pod
+        when multiple candidate driver pods are present and status does not disambiguate.
+        """
+
+        task_name = "test_find_spark_job_picks_latest_pod"
+        job_spec = yaml.safe_load(data_file("spark/application_template.yaml").read_text())
+
+        mock_create_job_name.return_value = task_name
+        op = SparkKubernetesOperator(
+            template_spec=job_spec,
+            kubernetes_conn_id="kubernetes_default_kube_config",
+            task_id=task_name,
+            get_logs=True,
+            reattach_on_restart=True,
+        )
+
+        context = create_context(op)
+
+        # Latest pod should be selected.
+        new_pod = mock.MagicMock()
+        new_pod.metadata.creation_timestamp = timezone.datetime(2025, 1, 3, tzinfo=timezone.utc)
+        new_pod.metadata.name = "spark-driver"
+        new_pod.metadata.labels = {"try_number": "1"}
+        new_pod.status.phase = PodPhase.RUNNING
+
+        # Older pod should not be selected.
+        old_pod = mock.MagicMock()
+        old_pod.metadata.creation_timestamp = timezone.datetime(2025, 1, 1, tzinfo=timezone.utc)
+        old_pod.metadata.name = "spark-driver"
+        old_pod.metadata.labels = {"try_number": "1"}
+        old_pod.status.phase = PodPhase.RUNNING
+
+        mock_get_kube_client.list_namespaced_pod.return_value.items = [
+            old_pod,
+            new_pod,
+        ]
+
+        returned_pod = op.find_spark_job(context)
+
+        assert returned_pod is new_pod
+
+    def test_find_spark_job_tiebreaks_by_name(
+        self,
+        mock_is_in_cluster,
+        mock_parent_execute,
+        mock_create_namespaced_crd,
+        mock_get_namespaced_custom_object_status,
+        mock_cleanup,
+        mock_create_job_name,
+        mock_get_kube_client,
+        mock_create_pod,
+        mock_await_pod_completion,
+        mock_fetch_requested_container_logs,
+        data_file,
+    ):
+        """
+        Verifies that find_spark_job uses pod name as a deterministic tie-breaker
+        when multiple running Spark driver pods share the same creation_timestamp.
+        """
+
+        task_name = "test_find_spark_job_tiebreaks_by_name"
+        job_spec = yaml.safe_load(data_file("spark/application_template.yaml").read_text())
+
+        mock_create_job_name.return_value = task_name
+        op = SparkKubernetesOperator(
+            template_spec=job_spec,
+            kubernetes_conn_id="kubernetes_default_kube_config",
+            task_id=task_name,
+            get_logs=True,
+            reattach_on_restart=True,
+        )
+        context = create_context(op)
+
+        # Use identical creation timestamps to force name-based tie-breaking.
+        ts = timezone.datetime(2025, 1, 1, tzinfo=timezone.utc)
+
+        # Pod with lexicographically smaller name should not be selected.
+        invalid_mock_pod = mock.MagicMock()
+        invalid_mock_pod.metadata.creation_timestamp = ts
+        invalid_mock_pod.metadata.name = "spark-driver-abc"
+        invalid_mock_pod.metadata.labels = {"try_number": "1"}
+        invalid_mock_pod.status.phase = PodPhase.RUNNING
+
+        # Pod with lexicographically greater name should be selected.
+        valid_mock_pod = mock.MagicMock()
+        valid_mock_pod.metadata.creation_timestamp = ts
+        valid_mock_pod.metadata.name = "spark-driver-xyz"
+        valid_mock_pod.metadata.labels = {"try_number": "1"}
+        valid_mock_pod.status.phase = PodPhase.RUNNING
+
+        mock_get_kube_client.list_namespaced_pod.return_value.items = [invalid_mock_pod, valid_mock_pod]
+
+        returned_pod = op.find_spark_job(context)
+
+        assert returned_pod is valid_mock_pod
+
     @pytest.mark.asyncio
     def test_execute_deferrable(
         self,
@@ -993,32 +1277,26 @@ def test_template_body_templating(create_task_instance_of_operator, session):
     )
     session.add(ti)
     session.commit()
-    ti.render_templates()
-    task: SparkKubernetesOperator = ti.task
+    task = ti.render_templates()
     assert task.template_body == {"spark": {"foo": "2016-01-01", "bar": "test_template_body_templating_dag"}}
 
 
 @pytest.mark.db_test
-def test_resolve_application_file_template_file(dag_maker, tmp_path, session):
-    logical_date = timezone.datetime(2024, 2, 1, tzinfo=timezone.utc)
+def test_resolve_application_file_template_file(create_task_instance_of_operator, tmp_path, session):
     filename = "test-application-file.yml"
     (tmp_path / filename).write_text("foo: {{ ds }}\nbar: {{ dag_run.dag_id }}\nspam: egg")
 
-    with dag_maker(
+    ti = create_task_instance_of_operator(
+        SparkKubernetesOperator,
         dag_id="test_resolve_application_file_template_file",
         template_searchpath=tmp_path.as_posix(),
+        task_id="test_template_body_templating_task",
+        application_file=filename,
+        kubernetes_conn_id="kubernetes_default_kube_config",
+        logical_date=timezone.datetime(2024, 2, 1, tzinfo=timezone.utc),
         session=session,
-    ):
-        SparkKubernetesOperator(
-            application_file=filename,
-            kubernetes_conn_id="kubernetes_default_kube_config",
-            task_id="test_template_body_templating_task",
-        )
-    ti = dag_maker.create_dagrun(logical_date=logical_date).task_instances[0]
-    session.add(ti)
-    session.commit()
-    ti.render_templates()
-    task: SparkKubernetesOperator = ti.task
+    )
+    task = ti.render_templates()
     assert task.template_body == {
         "spark": {
             "foo": date(2024, 2, 1),
@@ -1038,27 +1316,28 @@ def test_resolve_application_file_template_file(dag_maker, tmp_path, session):
         pytest.param(None, id="none"),
     ],
 )
-def test_resolve_application_file_template_non_dictionary(dag_maker, tmp_path, body, session):
+def test_resolve_application_file_template_non_dictionary(
+    create_task_instance_of_operator,
+    tmp_path,
+    body,
+    session,
+):
     logical_date = timezone.datetime(2024, 2, 1, tzinfo=timezone.utc)
     filename = "test-application-file.yml"
     with open((tmp_path / filename), "w") as fp:
         yaml.safe_dump(body, fp)
 
-    with dag_maker(
+    ti = create_task_instance_of_operator(
+        SparkKubernetesOperator,
         dag_id="test_resolve_application_file_template_nondictionary",
         template_searchpath=tmp_path.as_posix(),
+        task_id="test_template_body_templating_task",
+        application_file=filename,
+        kubernetes_conn_id="kubernetes_default_kube_config",
+        logical_date=logical_date,
         session=session,
-    ):
-        SparkKubernetesOperator(
-            application_file=filename,
-            kubernetes_conn_id="kubernetes_default_kube_config",
-            task_id="test_template_body_templating_task",
-        )
-    ti = dag_maker.create_dagrun(logical_date=logical_date).task_instances[0]
-    session.add(ti)
-    session.commit()
-    ti.render_templates()
-    task: SparkKubernetesOperator = ti.task
+    )
+    task = ti.render_templates()
     with pytest.raises(TypeError, match="application_file body can't transformed into the dictionary"):
         _ = task.template_body
 
@@ -1094,11 +1373,7 @@ def test_resolve_application_file_real_file(
         task_id="test_template_body_templating_task",
         session=session,
     )
-    session.add(ti)
-    session.commit()
-    ti.render_templates()
-    task: SparkKubernetesOperator = ti.task
-
+    task = ti.render_templates()
     assert task.template_body == {"spark": {"foo": "bar", "spam": "egg"}}
 
 
@@ -1119,10 +1394,7 @@ def test_resolve_application_file_real_file_not_exists(create_task_instance_of_o
         task_id="test_template_body_templating_task",
         session=session,
     )
-    session.add(ti)
-    session.commit()
-    ti.render_templates()
-    task: SparkKubernetesOperator = ti.task
+    task = ti.render_templates()
     with pytest.raises(TypeError, match="application_file body can't transformed into the dictionary"):
         _ = task.template_body
 
